v_platform library
Classes
- VPlatformFile
-
VPlatformFileis a class to handle various file sources such as local file path, byte array, URL, and assets. It provides utility methods for accessing file information like MIME type, media type, and size in human-readable format. - VPlatformFileUtils
- Abstract class to set a global base URL for media files. This can be accessed and set throughout the application.
- VPlatforms
- Cross-platform operating-system checks and multipart upload helpers.